<?php
/*
Plugin Name: Crear Tema Hijo
Description: Este plugin crea un tema hijo de un tema existente en WordPress.
*/

// Función para agregar una página de configuración al menú de administración
function crear_tema_hijo_menu() {
    add_menu_page(
        'Crear Tema Hijo',     // Título de la página
        'Crear Tema Hijo',     // Título del menú
        'manage_options',      // Capacidad requerida para acceder al menú
        'crear-tema-hijo',     // Slug de la página
        'crear_tema_hijo_pagina' // Función que mostrará la página
    );
}
add_action('admin_menu', 'crear_tema_hijo_menu');

// Función para mostrar el formulario en la página de configuración
function crear_tema_hijo_pagina() {
    if (isset($_POST['submit'])) {
        // Procesar el formulario cuando se envíe
        $nombre_tema = sanitize_text_field($_POST['nombre_tema']);
        $nombre_tema_padre = get_template(); // Obtener automáticamente el nombre del tema padre
        $imagen_tema = $_FILES['imagen_tema']['name'];
        
        // Crear el tema hijo
        crear_tema_hijo($nombre_tema, $nombre_tema_padre, $imagen_tema);
    }
    ?>
    <div class="wrap">
        <h2>Crear Tema Hijo</h2>
        <form method="post" enctype="multipart/form-data">
            <label for="nombre_tema">Nombre del Tema Hijo:</label>
            <input type="text" id="nombre_tema" name="nombre_tema" required><br><br>
            
            <label for="imagen_tema">Imagen del Tema Hijo:</label>
            <input type="file" id="imagen_tema" name="imagen_tema" accept="image/*"><br><br>
            
            <input type="submit" name="submit" value="Crear Tema Hijo">
        </form>
    </div>
    <?php
}

// Función para crear un tema hijo
function crear_tema_hijo($nombre_tema, $nombre_tema_padre, $imagen_tema) {
    $nombre_tema_padre = strtolower($nombre_tema_padre); // Convertir a minúsculas para evitar problemas de sintaxis
    
    $nombre_tema_hijo = sanitize_title($nombre_tema);
    
    // Directorio para el tema hijo
    $directorio_base = get_stylesheet_directory();
    $directorio_tema_hijo = $directorio_base . '/../../themes/' . $nombre_tema_hijo;

    echo "<p>Directorio del tema hijo: $directorio_tema_hijo</p>";
    
    // Verificar si el directorio del tema hijo ya existe
    if (is_dir($directorio_tema_hijo)) {
        echo '<p>El directorio del tema hijo ya existe.</p>';
        return;
    }
    
    // Crear directorio para el tema hijo
    if (!mkdir($directorio_tema_hijo) && !is_dir($directorio_tema_hijo)) {
        echo '<p>Error: No se pudo crear el directorio del tema hijo.</p>';
        return;
    } else {
        echo '<p>Directorio del tema hijo creado correctamente.</p>';
    }
    
    // Copiar la imagen del tema hijo
    $imagen_tema_destino = $directorio_tema_hijo . '/screenshot.png'; // Puedes cambiar 'screenshot.png' por el nombre de la imagen que desees
    if (!move_uploaded_file($_FILES['imagen_tema']['tmp_name'], $imagen_tema_destino)) {
        echo '<p>Error: No se pudo mover la imagen del tema hijo.</p>';
        return;
    } else {
        echo '<p>Imagen del tema hijo movida correctamente.</p>';
    }
    
    // Crear archivo style.css para el tema hijo
    $archivo_style_css = $directorio_tema_hijo . '/style.css';
    $contenido_style_css = "
/*
Theme Name: $nombre_tema
Theme URI: 
Description: Tema hijo de $nombre_tema_padre
Version: 1.0
Author: Óscar Amate
Author URI: https://oscaramate.dev/
Template: $nombre_tema_padre
*/

@import url('../$nombre_tema_padre/style.css');";
    if (!file_put_contents($archivo_style_css, $contenido_style_css)) {
        echo '<p>Error: No se pudo crear el archivo style.css del tema hijo.</p>';
        return;
    } else {
        echo '<p>Archivo style.css del tema hijo creado correctamente.</p>';
    }
// Crear archivo functions.php vacío para el tema hijo
$archivo_functions_php = $directorio_tema_hijo . '/functions.php';
$contenido_functions_php = '<?php // Este archivo está vacío.';
if (!file_put_contents($archivo_functions_php, $contenido_functions_php)) {
    echo '<p>Error: No se pudo crear el archivo functions.php del tema hijo.</p>';
    return;
} else {
    echo '<p>Archivo functions.php del tema hijo creado correctamente.</p>';
}

echo '<p>Se ha creado el tema hijo correctamente.</p>';
}